==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-telegram/src/main/java/org/apache/camel/component/telegram/model/InlineKeyboardButton.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.telegram.model;

import java.io.Serializable;
import java.util.Objects;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Represents one button of an inline keyboard. You must use exactly one of the optional fields.
 *
 * @see <a href="https://core.telegram.org/bots/api#inlinekeyboardbutton">
 *      https://core.telegram.org/bots/api#inlinekeyboardbutton</a>
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class InlineKeyboardButton implements Serializable {

    private static final long serialVersionUID = -5386858930543292655L;

    private String text;

    private String url;

    @JsonProperty("login_url")
    private LoginUrl loginUrl;

    @JsonProperty("callback_data")
    private String callbackData;

    @JsonProperty("callback_game")
    private CallbackGame callbackGame;

    @JsonProperty("request_contact")
    private Boolean requestContact;

    @JsonProperty("request_location")
    private Boolean requestLocation;

    public InlineKeyboardButton() {

    }

    /**
     * Builds {@link InlineKeyboardButton} instance.
     *
     * @param text            Label text on the button
     * @param url             Optional. HTTP or tg:// url to be opened when button is pressed
     * @param loginUrl        Optional. An HTTP URL used to automatically authorize the user.
     * @param callbackData    Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64
     *                        bytes
     * @param callbackGame    Optional. Description of the game that will be launched when the user presses the button.
     * @param requestContact  Optional. By clicking on the button, the user's phone will be sent.
     * @param requestLocation Optional. By clicking on the button, the user's location will be sent
     */
    public InlineKeyboardButton(String text, String url, LoginUrl loginUrl,
                                String callbackData, CallbackGame callbackGame,
                                Boolean requestContact, Boolean requestLocation) {
        this.text = text;
        this.url = url;
        this.loginUrl = loginUrl;
        this.callbackData = callbackData;
        this.callbackGame = callbackGame;
        this.requestContact = requestContact;
        this.requestLocation = requestLocation;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public LoginUrl getLoginUrl() {
        return loginUrl;
    }

    public void setLoginUrl(LoginUrl loginUrl) {
        this.loginUrl = loginUrl;
    }

    public String getCallbackData() {
        return callbackData;
    }

    public void setCallbackData(String callbackData) {
        this.callbackData = callbackData;
    }

    public CallbackGame getCallbackGame() {
        return callbackGame;
    }

    public void setCallbackGame(CallbackGame callbackGame) {
        this.callbackGame = callbackGame;
    }

    public Boolean getRequestContact() {
        return requestContact;
    }

    public void setRequestContact(Boolean requestContact) {
        this.requestContact = requestContact;
    }

    public Boolean getRequestLocation() {
        return requestLocation;
    }

    public void setRequestLocation(Boolean requestLocation) {
        this.requestLocation = requestLocation;
    }

    public static Builder builder() {
        return new Builder();
    }

    public static class Builder {

        private String text;
        private String url;
        private String callbackData;
        private LoginUrl loginUrl;
        private CallbackGame callbackGame;
        private Boolean requestContact;
        private Boolean requestLocation;

        public Builder text(String text) {
            this.text = text;
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            return this;
        }

        public Builder callbackData(String callbackData) {
            this.callbackData = callbackData;
            return this;
        }

        public Builder callbackGame(CallbackGame callbackGame) {
            this.callbackGame = callbackGame;
            return this;
        }

        public Builder loginUrl(LoginUrl loginUrl) {
            this.loginUrl = loginUrl;
            return this;
        }

        public Builder requestContact(Boolean requestContact) {
            this.requestContact = requestContact;
            return this;
        }

        public Builder requestLocation(Boolean requestLocation) {
            this.requestLocation = requestLocation;
            return this;
        }

        public InlineKeyboardButton build() {
            return new InlineKeyboardButton(text, url, loginUrl, callbackData, callbackGame, requestContact, requestLocation);
        }
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("InlineKeyboardButton{");
        sb.append("text='").append(text).append('\'');
        sb.append(", url='").append(url).append('\'');
        sb.append(", loginUrl=").append(loginUrl);
        sb.append(", callbackData='").append(callbackData).append('\'');
        sb.append(", callbackGame=").append(callbackGame);
        sb.append(", requestContact=").append(requestContact);
        sb.append(", requestLocation=").append(requestLocation);
        sb.append('}');
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineKeyboardButton that = (InlineKeyboardButton) o;
        return Objects.equals(text, that.text)
                && Objects.equals(url, that.url)
                && Objects.equals(loginUrl, that.loginUrl)
                && Objects.equals(callbackData, that.callbackData)
                && Objects.equals(callbackGame, that.callbackGame)
                && Objects.equals(requestContact, that.requestContact)
                && Objects.equals(requestLocation, that.requestLocation);
    }

    @Override
    public int hashCode() {
        return Objects.hash(text, url, loginUrl, callbackData, callbackGame, requestContact, requestLocation);
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-telegram/src/main/java/org/apache/camel/component/telegram/model/InlineKeyboardButton.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.telegram.model;

import java.io.Serializable;
import java.util.Objects;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Represents one button of an inline keyboard. You must use exactly one of the optional fields.
 *
 * @see <a href="https://core.telegram.org/bots/api#inlinekeyboardbutton">
 *      https://core.telegram.org/bots/api#inlinekeyboardbutton</a>
 */
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class InlineKeyboardButton implements Serializable {

    private static final long serialVersionUID = -5386858930543292655L;

    private String text;

    private String url;

    @JsonProperty("login_url")
    private LoginUrl loginUrl;

    @JsonProperty("callback_data")
    private String callbackData;

    @JsonProperty("callback_game")
    private CallbackGame callbackGame;

    @JsonProperty("request_contact")
    private Boolean requestContact;

    @JsonProperty("request_location")
    private Boolean requestLocation;

    private Boolean pay;

    public InlineKeyboardButton() {

    }

    /**
     * Builds {@link InlineKeyboardButton} instance.
     *
     * @param text            Label text on the button
     * @param url             Optional. HTTP or tg:// url to be opened when button is pressed
     * @param loginUrl        Optional. An HTTP URL used to automatically authorize the user.
     * @param callbackData    Optional. Data to be sent in a callback query to the bot when button is pressed, 1-64
     *                        bytes
     * @param callbackGame    Optional. Description of the game that will be launched when the user presses the button.
     * @param requestContact  Optional. By clicking on the button, the user's phone will be sent.
     * @param requestLocation Optional. By clicking on the button, the user's location will be sent
     */
    public InlineKeyboardButton(String text, String url, LoginUrl loginUrl,
                                String callbackData, CallbackGame callbackGame,
                                Boolean requestContact, Boolean requestLocation) {
        this(text, url, loginUrl, callbackData, callbackGame, requestContact, requestLocation, null);
    }

    public InlineKeyboardButton(String text, String url, LoginUrl loginUrl,
                                String callbackData, CallbackGame callbackGame,
                                Boolean requestContact, Boolean requestLocation, Boolean pay) {
        this.text = text;
        this.url = url;
        this.loginUrl = loginUrl;
        this.callbackData = callbackData;
        this.callbackGame = callbackGame;
        this.requestContact = requestContact;
        this.requestLocation = requestLocation;
        this.pay = pay;
    }

    public String getText() {
        return text;
    }

    public void setText(String text) {
        this.text = text;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public LoginUrl getLoginUrl() {
        return loginUrl;
    }

    public void setLoginUrl(LoginUrl loginUrl) {
        this.loginUrl = loginUrl;
    }

    public String getCallbackData() {
        return callbackData;
    }

    public void setCallbackData(String callbackData) {
        this.callbackData = callbackData;
    }

    public CallbackGame getCallbackGame() {
        return callbackGame;
    }

    public void setCallbackGame(CallbackGame callbackGame) {
        this.callbackGame = callbackGame;
    }

    public Boolean getRequestContact() {
        return requestContact;
    }

    public void setRequestContact(Boolean requestContact) {
        this.requestContact = requestContact;
    }

    public Boolean getRequestLocation() {
        return requestLocation;
    }

    public void setRequestLocation(Boolean requestLocation) {
        this.requestLocation = requestLocation;
    }

    public Boolean getPay() {
        return pay;
    }

    public void setPay(Boolean pay) {
        this.pay = pay;
    }

    public static Builder builder() {
        return new Builder();
    }

    public static class Builder {

        private String text;
        private String url;
        private String callbackData;
        private LoginUrl loginUrl;
        private CallbackGame callbackGame;
        private Boolean requestContact;
        private Boolean requestLocation;
        private Boolean pay;

        public Builder text(String text) {
            this.text = text;
            return this;
        }

        public Builder url(String url) {
            this.url = url;
            return this;
        }

        public Builder callbackData(String callbackData) {
            this.callbackData = callbackData;
            return this;
        }

        public Builder callbackGame(CallbackGame callbackGame) {
            this.callbackGame = callbackGame;
            return this;
        }

        public Builder loginUrl(LoginUrl loginUrl) {
            this.loginUrl = loginUrl;
            return this;
        }

        public Builder requestContact(Boolean requestContact) {
            this.requestContact = requestContact;
            return this;
        }

        public Builder requestLocation(Boolean requestLocation) {
            this.requestLocation = requestLocation;
            return this;
        }

        public Builder pay(Boolean pay) {
            this.pay = pay;
            return this;
        }

        public InlineKeyboardButton build() {
            return new InlineKeyboardButton(
                    text, url, loginUrl, callbackData, callbackGame, requestContact, requestLocation, pay);
        }
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("InlineKeyboardButton{");
        sb.append("text='").append(text).append('\'');
        sb.append(", url='").append(url).append('\'');
        sb.append(", loginUrl=").append(loginUrl);
        sb.append(", callbackData='").append(callbackData).append('\'');
        sb.append(", callbackGame=").append(callbackGame);
        sb.append(", requestContact=").append(requestContact);
        sb.append(", requestLocation=").append(requestLocation);
        sb.append(", pay=").append(pay);
        sb.append('}');
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineKeyboardButton that = (InlineKeyboardButton) o;
        return Objects.equals(text, that.text)
                && Objects.equals(url, that.url)
                && Objects.equals(loginUrl, that.loginUrl)
                && Objects.equals(callbackData, that.callbackData)
                && Objects.equals(callbackGame, that.callbackGame)
                && Objects.equals(requestContact, that.requestContact)
                && Objects.equals(requestLocation, that.requestLocation)
                && Objects.equals(pay, that.pay);
    }

    @Override
    public int hashCode() {
        return Objects.hash(text, url, loginUrl, callbackData, callbackGame, requestContact, requestLocation, pay);
    }
}
